package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Aug 2, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Meta struct {
ID id.ID `json:"id"`
TrashTime time.Time `json:"trash_time"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.